@@ -359,7 +359,7 @@ void PropagateDownloadFile::start()
     // For virtual files just dehydrate or create the file and be done
     if (_item->_type == ItemTypeVirtualFileDehydration) {
         const QString fsPath = propagator()->fullLocalPath(_item->_file);
-        if (!FileSystem::verifyFileUnchanged(fsPath, _item->_previousSize, _item->_previousModtime)) {
+        if (FileSystem::fileChanged(fsPath, _item->_previousSize, _item->_previousModtime)) {
             propagator()->_anotherSyncNeeded = true;
             done(SyncFileItem::SoftError, tr("File has changed since discovery"));
             return;
@@ -370,12 +370,6 @@ void PropagateDownloadFile::start()
             return;
         }
         qCDebug(lcPropagateDownload) << "dehydrating file" << _item->_file;
-        auto r = vfs->dehydratePlaceholder(*_item);
-        if (!r) {
-            done(SyncFileItem::NormalError, r.error());
-            return;
-        }
-        propagator()->_journal->deleteFileRecord(_item->_originalFile);
         updateMetadata(false);
         return;
     }
@@ -710,7 +704,7 @@ void PropagateDownloadFile::slotGetFinished()
         // This happened when trying to resume a file. The Content-Range header was files, Content-Length was == 0
         qCDebug(lcPropagateDownload) << bodySize << _item->_size << _tmpFile.size() << job->resumeStart();
         FileSystem::remove(_tmpFile.fileName());
-        done(SyncFileItem::SoftError, QStringLiteral("Broken webserver returning empty content length for non-empty file on resume"));
+        done(SyncFileItem::SoftError, tr("Broken webserver returned empty content length for non-empty file on resume"));
         return;
     }
 
@@ -954,7 +948,7 @@ void PropagateDownloadFile::downloadFinished()
         // the discovery phase and now.
         const qint64 expectedSize = _item->_previousSize;
         const time_t expectedMtime = _item->_previousModtime;
-        if (!FileSystem::verifyFileUnchanged(fn, expectedSize, expectedMtime)) {
+        if (FileSystem::fileChanged(fn, expectedSize, expectedMtime)) {
             propagator()->_anotherSyncNeeded = true;
             done(SyncFileItem::SoftError, tr("File has changed since discovery"));
             return;
