@@ -61,6 +61,21 @@ static bool fileIsStillChanging(const SyncFileItem &item)
         && msSinceMod > -10000;
 }
 
+PUTFileJob::PUTFileJob(AccountPtr account, const QString &path, std::unique_ptr<QIODevice> device, const QMap<QByteArray, QByteArray> &headers, int chunk, QObject *parent)
+    : PUTFileJob(account, Utility::concatUrlPath(account->davUrl(), path), std::move(device), headers, chunk, parent)
+{
+}
+
+PUTFileJob::PUTFileJob(AccountPtr account, const QUrl &url, std::unique_ptr<QIODevice> device, const QMap<QByteArray, QByteArray> &headers, int chunk, QObject *parent)
+    : AbstractNetworkJob(account, QString(), parent)
+    , _device(device.release())
+    , _headers(headers)
+    , _url(url)
+    , _chunk(chunk)
+{
+    _device->setParent(this);
+}
+
 PUTFileJob::~PUTFileJob()
 {
     // Make sure that we destroy the QNetworkReply before our _device of which it keeps an internal pointer.
@@ -76,13 +91,8 @@ void PUTFileJob::start()
 
     req.setPriority(QNetworkRequest::LowPriority); // Long uploads must not block non-propagation jobs.
 
-    if (_url.isValid()) {
-        sendRequest("PUT", _url, req, _device);
-    } else {
-        sendRequest("PUT", makeDavUrl(path()), req, _device);
-    }
+    sendRequest("PUT", _url, req, _device);
 
-    connect(reply(), &QNetworkReply::uploadProgress, this, &PUTFileJob::uploadProgress);
     connect(this, &AbstractNetworkJob::networkActivity, account().data(), &Account::propagatorNetworkActivity);
     _requestTimer.start();
     AbstractNetworkJob::start();
@@ -101,6 +111,11 @@ bool PUTFileJob::finished()
     return true;
 }
 
+void PUTFileJob::newReplyHook(QNetworkReply *reply)
+{
+    connect(reply, &QNetworkReply::uploadProgress, this, &PUTFileJob::uploadProgress);
+}
+
 void PropagateUploadFileCommon::setDeleteExisting(bool enabled)
 {
     _deleteExisting = enabled;
@@ -225,26 +240,19 @@ void PropagateUploadFileCommon::slotStartUpload(const QByteArray &transmissionCh
         done(SyncFileItem::SoftError, tr("File Removed"));
         return;
     }
-    time_t prevModtime = _item->_modtime; // the _item value was set in PropagateUploadFile::start()
+    _item->_size = FileSystem::getSize(fullFilePath);
+
+    const time_t prevModtime = _item->_modtime; // the _item value was set in PropagateUploadFile::start()
     // but a potential checksum calculation could have taken some time during which the file could
     // have been changed again, so better check again here.
 
-    _item->_modtime = FileSystem::getModTime(fullFilePath);
-    if (prevModtime != _item->_modtime) {
-        propagator()->_anotherSyncNeeded = true;
-        done(SyncFileItem::SoftError, tr("Local file changed during syncing. It will be resumed."));
-        return;
-    }
-
-    qint64 fileSize = FileSystem::getSize(fullFilePath);
-    _item->_size = fileSize;
-
     // But skip the file if the mtime is too close to 'now'!
     // That usually indicates a file that is still being changed
     // or not yet fully copied to the destination.
-    if (fileIsStillChanging(*_item)) {
+    _item->_modtime = FileSystem::getModTime(fullFilePath);
+    if (prevModtime != _item->_modtime || fileIsStillChanging(*_item)) {
         propagator()->_anotherSyncNeeded = true;
-        done(SyncFileItem::SoftError, tr("Local file changed during sync."));
+        done(SyncFileItem::Message, tr("Local file changed during sync. It will be resumed."));
         return;
     }
 
@@ -501,10 +509,11 @@ void PropagateUploadFileCommon::slotJobDestroyed(QObject *job)
 // This function is used whenever there is an error occuring and jobs might be in progress
 void PropagateUploadFileCommon::abortWithError(SyncFileItem::Status status, const QString &error)
 {
-    if (_aborting)
-        return;
-    abort(AbortType::Synchronous);
-    done(status, error);
+    qCWarning(lcPropagateUpload) << Q_FUNC_INFO << _item->_file << error;
+    if (!_aborting) {
+        abort(AbortType::Synchronous);
+        done(status, error);
+    }
 }
 
 QMap<QByteArray, QByteArray> PropagateUploadFileCommon::headers()
@@ -573,6 +582,10 @@ void PropagateUploadFileCommon::finalize()
     if (quotaIt != propagator()->_folderQuota.end())
         quotaIt.value() -= _item->_size;
 
+
+#ifdef Q_OS_WIN
+    m_fileLock.close();
+#endif
     // Update the database entry
     const auto result = propagator()->updateMetadata(*_item);
     if (!result) {
