@@ -38,8 +38,17 @@ namespace OCC {
 
 void PropagateUploadFileV1::doStartUpload()
 {
-    if (!propagator()->account()->capabilities().bigfilechunkingEnabled())
-    {
+    const QString fileName = propagator()->fullLocalPath(_item->_file);
+    // If the file is currently locked, we want to retry the sync
+    // when it becomes available again.
+    const auto lockMode = propagator()->syncOptions().requiredLockMode();
+    if (FileSystem::isFileLocked(fileName, lockMode)) {
+        emit propagator()->seenLockedFile(fileName, lockMode);
+        abortWithError(SyncFileItem::SoftError, tr("%1 the file is currently in use").arg(QDir::toNativeSeparators(fileName)));
+        return;
+    }
+
+    if (!propagator()->account()->capabilities().bigfilechunkingEnabled()) {
         _chunkCount = 1;
     } else {
         _chunkCount = int(std::ceil(_item->_size / double(chunkSize())));
@@ -129,14 +138,6 @@ void PropagateUploadFileV1::startNextChunk()
     }
 
     const QString fileName = propagator()->fullLocalPath(_item->_file);
-    // If the file is currently locked, we want to retry the sync
-    // when it becomes available again.
-    const auto lockMode = propagator()->syncOptions().requiredLockMode();
-    if (FileSystem::isFileLocked(fileName, lockMode)) {
-        emit propagator()->seenLockedFile(fileName, lockMode);
-        abortWithError(SyncFileItem::SoftError, tr("%1 the file is currently in use").arg(fileName));
-        return;
-    }
     auto device = std::unique_ptr<UploadDevice>(new UploadDevice(
             fileName, chunkStart, currentChunkSize, &propagator()->_bandwidthManager));
     if (!device->open(QIODevice::ReadOnly)) {
@@ -247,7 +248,7 @@ void PropagateUploadFileV1::slotPutFinished()
     }
 
     // Check whether the file changed since discovery.
-    if (!FileSystem::verifyFileUnchanged(fullFilePath, _item->_size, _item->_modtime)) {
+    if (FileSystem::fileChanged(fullFilePath, _item->_size, _item->_modtime)) {
         propagator()->_anotherSyncNeeded = true;
         if (!_finished) {
             abortWithError(SyncFileItem::SoftError, tr("Local file changed during sync."));
